/**
 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
export declare const KEYS: {
    ARROW_DOWN: string;
    ARROW_LEFT: string;
    ARROW_RIGHT: string;
    ARROW_UP: string;
    BACKSPACE: string;
    CONTROL_C: string;
    CONTROL_D: string;
    CONTROL_U: string;
    ENTER: string;
    ESCAPE: string;
};
