/**
 * Copyright (c) Facebook, Inc. and its affiliates. All Rights Reserved.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import type { ScrollOptions } from '../types';
export default function scroll(size: number, { offset, max }: ScrollOptions): {
    end: number;
    index: number;
    start: number;
};
